# Welcome to openEPhys_DACQ repository.

This recording system works in synchrony with [Open Ephys GUI](https://github.com/open-ephys/plugin-GUI) and allows acquisition of video data from multiple cameras together with online tracking.

The package also includes a behavioural task for study of spatial navigation. The behavioural task involves physical actuators (reward modules) which can be built based on instructions in the documentation.

Please follow [this link for documentation](https://barry-lab.github.io/openEPhys_DACQ/index.html)
